==> redquicklib-1.550.0.tgz: package/lib/components/nubs.js <==
import React, { Component } from 'react';
import { connect } from 'react-redux';
import {
    View
} from 'native-base';
import * as utils from '../util/util';
import { Colors } from '../colors';
import * as Common from '../screens/customer/common';
import {
    Dimensions
} from 'react-native';
const { width, height } = Dimensions.get('window');

class Nubs extends Component {
    constructor(props) {
        super(props);
        this.state = {
            size: { width, height },
        };
    }
    _onLayoutDidChange = (e) => {
        const layout = e.nativeEvent.layout;
        this.setState({ size: { width: layout.width, height: layout.height } });
    }

    render() {
        var me = this;
        var choices = [].interpolate(0, this.props.count, e => { return {} });
        return (<View onLayout={this._onLayoutDidChange.bind(this)} style={{
            flexDirection: 'row', flex: 1, justifyContent: 'center',
            alignItems: 'center',
            alignContent: 'center', width
        }}>
            {choices.map((choice, i) => {
                var size = me.props.size;
                let color = null;
                if (me.props.active.indexOf(i) !== -1) {
                    size = 10;
                    color = this.props.activecolor || Colors.White;
                }
                else {
                    size = 7;
                    color = this.props.inactive || Colors.Grey;
                }
                return (<View style={{ padding: me.props.padding || 0 }} key={`choiceindex-${i}`}>{Common.Circle(null, {
                    borderRadius: size,
                    backgroundColor: color,
                    width: size,
                    height: size
                })}</View>);
            })}
        </View>)
    }
}

export default connect(utils.mapStateToProps, utils.mapDispatchToProps)(Nubs);

==> redquicklib-1.553.0.tgz: package/lib/components/nubs.js <==
import React, { Component } from 'react';
import { connect } from 'react-redux';
import {
    View
} from 'native-base';

import { Colors } from '../colors';
import {
    Dimensions
} from 'react-native';
const { width, height } = Dimensions.get('window');

class Nubs extends Component {
    constructor(props) {
        super(props);
        this.state = {
            size: { width, height },
        };
    }
    _onLayoutDidChange = (e) => {
        const layout = e.nativeEvent.layout;
        this.setState({ size: { width: layout.width, height: layout.height } });
    }

    render() {
        var me = this;
        var choices = [].interpolate(0, this.props.count, e => { return {} });
        return (<View onLayout={this._onLayoutDidChange.bind(this)} style={{
            flexDirection: 'row', flex: 1, justifyContent: 'center',
            alignItems: 'center',
            alignContent: 'center', width
        }}>
            {choices.map((choice, i) => {
                var size = me.props.size;
                let color = null;
                if (me.props.active.indexOf(i) !== -1) {
                    size = 10;
                    color = this.props.activecolor || Colors.White;
                }
                else {
                    size = 7;
                    color = this.props.inactive || Colors.Grey;
                }
                return (<View style={{ padding: me.props.padding || 0 }} key={`choiceindex-${i}`}>{Circle(null, {
                    borderRadius: size,
                    backgroundColor: color,
                    width: size,
                    height: size
                })}</View>);
            })}
        </View>)
    }
}

export const Circle = (children, style) => {
    return (
        <View style={style}>
            <View
                style={{
                    flex: 1,
                    alignItems: 'center',
                    flexDirection: 'column'
                }}>
                <View style={{
                    flex: 1,
                    alignItems: 'center',
                    flexDirection: 'row'
                }}>
                    {children}
                </View>
            </View>
        </View>
    )
}
export default connect(utils.mapStateToProps, utils.mapDispatchToProps)(Nubs);
